==> haskell-vector-instances-3.4-120-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-vector-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: vector-instances
version: 3.4
id: vector-instances-3.4-3rG4WdcqqDEDPAE306MNxA
key: vector-instances-3.4-3rG4WdcqqDEDPAE306MNxA
license: BSD-3-Clause
maintainer: ekmett@gmail.com
author: Edward Kmett
homepage: http://github.com/ekmett/vector-instances
synopsis: Orphan Instances for '\''Data.Vector'\''
category: Data, Data Structures
abi: 580b9bba15154ab75280a3b904ba8770
exposed: True
exposed-modules:
    Data.Vector.Instances
import-dirs: /usr/lib/ghc-8.6.5/site-local/vector-instances-3.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/vector-instances-3.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/vector-instances-3.4
hs-libraries: HSvector-instances-3.4-3rG4WdcqqDEDPAE306MNxA
depends:
    base-4.12.0.0 comonad-5.0.5-Jb7dZT99SDmElZXYIEXTJE
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    keys-3.12.2-JUQkZ9OOXwA3yKe2xEBNad
    pointed-5.0.1-IGNoI94MG7198o8JGJwLIW
    semigroupoids-5.3.2-5mbTYGts6oi5iNhZLYH5Nv
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-vector-instances/html/vector-instances.haddock
haddock-html: /usr/share/doc/haskell-vector-instances/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vector-instances-3.4-121-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-vector-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: vector-instances
version: 3.4
id: vector-instances-3.4-J6cquvpq7Kq6XAmUx5Ax5G
key: vector-instances-3.4-J6cquvpq7Kq6XAmUx5Ax5G
license: BSD-3-Clause
maintainer: ekmett@gmail.com
author: Edward Kmett
homepage: http://github.com/ekmett/vector-instances
synopsis: Orphan Instances for '\''Data.Vector'\''
category: Data, Data Structures
abi: 1cb37f382a5a308c08a29eb20ba375c9
exposed: True
exposed-modules:
    Data.Vector.Instances
import-dirs: /usr/lib/ghc-8.6.5/site-local/vector-instances-3.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/vector-instances-3.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/vector-instances-3.4
hs-libraries: HSvector-instances-3.4-J6cquvpq7Kq6XAmUx5Ax5G
depends:
    base-4.12.0.0 comonad-5.0.5-DmbDL80vNTBENwSEJV2LS7
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    keys-3.12.2-CvsNkugO8HCF9NUunb0PM9
    pointed-5.0.1-FR1ZXgZlLNIK9VeyY6EuEX
    semigroupoids-5.3.2-E8bBgioebzyBd6Df4R8d9J
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-vector-instances/html/vector-instances.haddock
haddock-html: /usr/share/doc/haskell-vector-instances/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
